@@ -4,7 +4,7 @@
  *   (http://liba52.sf.net/).
  *****************************************************************************
  * Copyright (C) 2001 VideoLAN
- * $Id: a52.c,v 1.11 2002/05/20 15:03:32 gbazin Exp $
+ * $Id: a52.c,v 1.14.2.2 2002/06/02 10:28:14 gbazin Exp $
  *
  * Authors: Gildas Bazin <gbazin@netcourrier.com>
  *      
@@ -28,10 +28,15 @@
  *****************************************************************************/
 #include <stdlib.h>                                      /* malloc(), free() */
 #include <string.h>                                              /* strdup() */
-#include <stdint.h>                                            /* int16_t .. */
 
 #include <videolan/vlc.h>
 
+#ifdef HAVE_STDINT_H
+#   include <stdint.h>                                         /* int16_t .. */
+#elif HAVE_INTTYPES_H
+#   include <inttypes.h>                                       /* int16_t .. */
+#endif
+
 #include "audio_output.h"
 
 #include "stream_control.h"
@@ -72,7 +77,7 @@ void _M( adec_getfunctions )( function_list_t * p_function_list )
 /*****************************************************************************
  * Build configuration structure.
  *****************************************************************************/
-#define DYNRNG_TEXT N_("disable A/52 dynamic range compression")
+#define DYNRNG_TEXT N_("A/52 dynamic range compression")
 #define DYNRNG_LONGTEXT N_( \
     "Dynamic range compression makes the loud sounds softer, and the soft " \
     "sounds louder, so you can more easily listen to the stream in a noisy " \
@@ -82,7 +87,7 @@ void _M( adec_getfunctions )( function_list_t * p_function_list )
 
 MODULE_CONFIG_START
 ADD_CATEGORY_HINT( N_("Miscellaneous"), NULL )
-ADD_BOOL    ( "a52-no-dynrng", NULL, DYNRNG_TEXT, DYNRNG_LONGTEXT )
+ADD_BOOL    ( "a52-dynrng", 1, NULL, DYNRNG_TEXT, DYNRNG_LONGTEXT )
 MODULE_CONFIG_STOP
 
 MODULE_INIT_START
@@ -158,6 +163,7 @@ static int decoder_Run ( decoder_config_t *p_config )
 
         /* get a52 frame header */
         GetChunk( &p_a52_adec->bit_stream, p_a52_adec->p_frame_buffer, 7 );
+	if( p_a52_adec->p_fifo->b_die ) break;
 
         /* check if frame is valid and get frame info */
         p_a52_adec->frame_size = a52_syncinfo( p_a52_adec->p_frame_buffer,
@@ -171,7 +177,7 @@ static int decoder_Run ( decoder_config_t *p_config )
             continue;
         }
 
-        if( DecodeFrame( p_a52_adec ) )
+        if( DecodeFrame( p_a52_adec ) && !p_a52_adec->p_fifo->b_die )
         {
             DecoderError( p_config->p_decoder_fifo );
             free( p_a52_adec );
@@ -208,7 +214,7 @@ static int InitThread( a52_adec_thread_t * p_a52_adec )
         return -1;
     }
 
-    p_a52_adec->b_dynrng = !config_GetIntVariable( "a52-no-dynrng" );
+    p_a52_adec->b_dynrng = config_GetIntVariable( "a52-dynrng" );
 
     /* Init the BitStream */
     InitBitstream( &p_a52_adec->bit_stream,
@@ -240,9 +246,9 @@ static int DecodeFrame( a52_adec_thread_t * p_a52_adec )
     }
 
     /* Creating the audio output fifo if not created yet */
-    if (p_a52_adec->p_aout_fifo == NULL )
+    if( p_a52_adec->p_aout_fifo == NULL )
     {
-        p_a52_adec->p_aout_fifo = aout_CreateFifo( AOUT_FIFO_PCM, 
+        p_a52_adec->p_aout_fifo = aout_CreateFifo( AOUT_FIFO_PCM,
                                     p_a52_adec->i_channels,
                                     p_a52_adec->sample_rate,
                                     AC3DEC_FRAME_SIZE * p_a52_adec->i_channels,
@@ -279,6 +285,7 @@ static int DecodeFrame( a52_adec_thread_t * p_a52_adec )
     /* Get the complete frame */
     GetChunk( &p_a52_adec->bit_stream, p_a52_adec->p_frame_buffer + 7,
               p_a52_adec->frame_size - 7 );
+    if( p_a52_adec->p_fifo->b_die ) return( -1 );
 
     /* do the actual decoding now */
     a52_frame( p_a52_adec->p_a52_state, p_a52_adec->p_frame_buffer,
@@ -365,6 +372,6 @@ static void BitstreamCallback ( bit_stream_t * p_bit_stream,
     if( b_new_pes )
     {
         /* Drop special AC3 header */
-        p_bit_stream->p_byte += 3;
+/*        p_bit_stream->p_byte += 3; */
     }
 }
