@@ -2,7 +2,7 @@
  * vout_events.c: Windows DirectX video output events handler
  *****************************************************************************
  * Copyright (C) 2001 VideoLAN
- * $Id: vout_events.c,v 1.18 2002/05/18 22:41:43 gbazin Exp $
+ * $Id: vout_events.c,v 1.18.2.2 2002/06/03 17:19:54 sam Exp $
  *
  * Authors: Gildas Bazin <gbazin@netcourrier.com>
  *
@@ -140,10 +140,22 @@ void DirectXEventThread( vout_thread_t *p_vout )
             switch( msg.wParam )
             {
             case VK_ESCAPE:
-            case VK_F12:
                 /* exit application */
                 p_main->p_intf->b_die = 1;
                 break;
+
+            case VK_F1: network_ChannelJoin( 1 ); break;
+            case VK_F2: network_ChannelJoin( 2 ); break;
+            case VK_F3: network_ChannelJoin( 3 ); break;
+            case VK_F4: network_ChannelJoin( 4 ); break;
+            case VK_F5: network_ChannelJoin( 5 ); break;
+            case VK_F6: network_ChannelJoin( 6 ); break;
+            case VK_F7: network_ChannelJoin( 7 ); break;
+            case VK_F8: network_ChannelJoin( 8 ); break;
+            case VK_F9: network_ChannelJoin( 9 ); break;
+            case VK_F10: network_ChannelJoin( 10 ); break;
+            case VK_F11: network_ChannelJoin( 11 ); break;
+            case VK_F12: network_ChannelJoin( 12 ); break;
             }
             TranslateMessage(&msg);
             break;
@@ -185,17 +197,6 @@ void DirectXEventThread( vout_thread_t *p_vout )
                 p_vout->p_sys->i_changes |= VOUT_INTF_CHANGE;
                 break;
 
-            case '0': network_ChannelJoin( 0 ); break;
-            case '1': network_ChannelJoin( 1 ); break;
-            case '2': network_ChannelJoin( 2 ); break;
-            case '3': network_ChannelJoin( 3 ); break;
-            case '4': network_ChannelJoin( 4 ); break;
-            case '5': network_ChannelJoin( 5 ); break;
-            case '6': network_ChannelJoin( 6 ); break;
-            case '7': network_ChannelJoin( 7 ); break;
-            case '8': network_ChannelJoin( 8 ); break;
-            case '9': network_ChannelJoin( 9 ); break;
-
             default:
                 break;
             }
