@@ -6,7 +6,7 @@
  * It depends on: libdvdread for ifo files and block reading.
  *****************************************************************************
  * Copyright (C) 2001 VideoLAN
- * $Id: input_dvdread.c,v 1.35 2002/04/03 16:22:23 sam Exp $
+ * $Id: input_dvdread.c,v 1.38 2002/05/14 19:33:54 bozo Exp $
  *
  * Author: Stphane Borel <stef@via.ecp.fr>
  *
@@ -76,8 +76,6 @@
 
 #include "iso_lang.h"
 
-#include "debug.h"
-
 /* how many blocks DVDRead will read in each loop */
 #define DVD_BLOCK_READ_ONCE 64
 
@@ -295,7 +293,7 @@ static int DvdReadOpen( struct input_thread_s *p_input )
             free( psz_orig );
             return -1;
         }
-        psz_source = config_GetPszVariable( "dvd_device" );
+        psz_source = config_GetPszVariable( "dvd" );
     }
 
     if( stat( psz_source, &stat_info ) == -1 )
@@ -685,8 +683,8 @@ static int DvdReadSetArea( input_thread_t * p_input, input_area_t * p_area )
                     p_es->i_type = AC3_AUDIO_ES;
                     p_es->b_audio = 1;
                     p_es->i_cat = AUDIO_ES;
-                    strcpy( p_es->psz_desc, DecodeLanguage( hton16(
-                        p_vts->vtsi_mat->vts_audio_attr[i-1].lang_code ) ) ); 
+                    strcpy( p_es->psz_desc, DecodeLanguage(
+                        p_vts->vtsi_mat->vts_audio_attr[i-1].lang_code ) ); 
                     strcat( p_es->psz_desc, " (ac3)" );
 
                     break;
@@ -698,8 +696,8 @@ static int DvdReadSetArea( input_thread_t * p_input, input_area_t * p_area )
                     p_es->i_type = MPEG2_AUDIO_ES;
                     p_es->b_audio = 1;
                     p_es->i_cat = AUDIO_ES;
-                    strcpy( p_es->psz_desc, DecodeLanguage( hton16(
-                        p_vts->vtsi_mat->vts_audio_attr[i-1].lang_code ) ) ); 
+                    strcpy( p_es->psz_desc, DecodeLanguage(
+                        p_vts->vtsi_mat->vts_audio_attr[i-1].lang_code ) ); 
                     strcat( p_es->psz_desc, " (mpeg)" );
 
                     break;
@@ -711,8 +709,8 @@ static int DvdReadSetArea( input_thread_t * p_input, input_area_t * p_area )
                     p_es->i_type = LPCM_AUDIO_ES;
                     p_es->b_audio = 1;
                     p_es->i_cat = AUDIO_ES;
-                    strcpy( p_es->psz_desc, DecodeLanguage( hton16(
-                        p_vts->vtsi_mat->vts_audio_attr[i-1].lang_code ) ) ); 
+                    strcpy( p_es->psz_desc, DecodeLanguage(
+                        p_vts->vtsi_mat->vts_audio_attr[i-1].lang_code ) ); 
                     strcat( p_es->psz_desc, " (lpcm)" );
 
                     break;
@@ -774,8 +772,8 @@ static int DvdReadSetArea( input_thread_t * p_input, input_area_t * p_area )
                 p_es->i_stream_id = 0xbd;
                 p_es->i_type = DVD_SPU_ES;
                 p_es->i_cat = SPU_ES;
-                strcpy( p_es->psz_desc, DecodeLanguage( hton16(
-                    p_vts->vtsi_mat->vts_subp_attr[i-1].lang_code ) ) ); 
+                strcpy( p_es->psz_desc, DecodeLanguage(
+                    p_vts->vtsi_mat->vts_subp_attr[i-1].lang_code ) ); 
             }
         }
 #undef spu_control
@@ -1219,15 +1217,15 @@ static void DvdReadLauchDecoders( input_thread_t * p_input )
     if( p_main->b_audio )
     {
         /* For audio: first one if none or a not existing one specified */
-        int i_audio = config_GetIntVariable( "input_channel" );
+        int i_audio = config_GetIntVariable( "audio-channel" );
         if( i_audio < 0 /*|| i_audio > i_audio_nb*/ )
         {
-            config_PutIntVariable( "input_channel", 1 );
+            config_PutIntVariable( "audio-channel", 1 );
             i_audio = 1;
         }
         if( i_audio > 0/* && i_audio_nb > 0*/ )
         {
-            if( config_GetIntVariable( "input_audio" ) == REQUESTED_AC3 )
+            if( config_GetIntVariable( "audio-type" ) == REQUESTED_AC3 )
             {
                 int     i_ac3 = i_audio;
                 while( ( p_input->stream.pp_es[i_ac3]->i_type !=
@@ -1253,10 +1251,10 @@ static void DvdReadLauchDecoders( input_thread_t * p_input )
     if( p_main->b_video )
     {
         /* for spu, default is none */
-        int i_spu = config_GetIntVariable( "input_subtitle" );
+        int i_spu = config_GetIntVariable( "spu-channel" );
         if( i_spu < 0 /*|| i_spu > i_spu_nb*/ )
         {
-            config_PutIntVariable( "input_subtitle", 0 );
+            config_PutIntVariable( "spu-channel", 0 );
             i_spu = 0;
         }
         if( i_spu > 0 /*&& i_spu_nb > 0*/ )
