@@ -2,7 +2,7 @@
  * idct.c : C IDCT module
  *****************************************************************************
  * Copyright (C) 1999-2001 VideoLAN
- * $Id: idct.c,v 1.20 2002/02/15 13:32:53 sam Exp $
+ * $Id: idct.c,v 1.23 2002/05/18 17:47:46 sam Exp $
  *
  * Author: Gal Hendryckx <jimmy@via.ecp.fr>
  *
@@ -44,7 +44,7 @@ MODULE_CONFIG_START
 MODULE_CONFIG_STOP
 
 MODULE_INIT_START
-    SET_DESCRIPTION( "IDCT module" )
+    SET_DESCRIPTION( _("IDCT module") )
     ADD_CAPABILITY( IDCT, 50 )
     ADD_SHORTCUT( "c" )
     ADD_SHORTCUT( "idct" )
@@ -69,7 +69,7 @@ static void NormScan( u8 ppi_scan[2][64] )
 /*****************************************************************************
  * IDCT : IDCT function for normal matrices
  *****************************************************************************/
-static __inline__ void IDCT( dctelem_t * p_block )
+static inline void IDCT( dctelem_t * p_block )
 {
     s32 tmp0, tmp1, tmp2, tmp3;
     s32 tmp10, tmp11, tmp12, tmp13;
@@ -1247,5 +1247,10 @@ static __inline__ void IDCT( dctelem_t * p_block )
     }
 }
 
+static inline void RestoreCPUState( )
+{
+    ;
+}
+
 #include "idct_sparse.h"
 #include "idct_decl.h"
