@@ -2,7 +2,7 @@
  * intf_vlc_wrapper.c: MacOS X plugin for vlc
  *****************************************************************************
  * Copyright (C) 2001 VideoLAN
- * $Id: intf_vlc_wrapper.m,v 1.6 2002/05/19 23:51:37 massiot Exp $
+ * $Id: intf_vlc_wrapper.m,v 1.6.2.6 2002/06/03 00:28:07 sam Exp $
  *
  * Authors: Florian G. Pflug <fgp@phlo.org>
  *          Jon Lech Johansen <jon-vl@nanocrew.net>
@@ -202,6 +202,58 @@ static Intf_VLCWrapper *o_intf = nil;
     }
 }
 
+- (void)channelNext
+{
+    intf_thread_t * p_intf = p_main->p_intf;
+
+    p_intf->p_sys->i_channel++;
+
+    intf_WarnMsg( 3, "intf info: joining channel %d", p_intf->p_sys->i_channel );
+
+    vlc_mutex_lock( &p_intf->change_lock );
+
+    network_ChannelJoin( p_intf->p_sys->i_channel );
+    p_intf->pf_manage( p_intf );
+
+    vlc_mutex_unlock( &p_intf->change_lock );
+}
+
+- (void)channelPrev
+{
+    intf_thread_t * p_intf = p_main->p_intf;
+
+    if ( p_intf->p_sys->i_channel )
+    {
+        p_intf->p_sys->i_channel--;
+    }
+
+    intf_WarnMsg( 3, "intf info: joining channel %d", p_intf->p_sys->i_channel );
+
+    vlc_mutex_lock( &p_intf->change_lock );
+
+    network_ChannelJoin( p_intf->p_sys->i_channel );
+    p_intf->pf_manage( p_intf );
+
+    vlc_mutex_unlock( &p_intf->change_lock );
+}
+
+- (void)loop
+{
+    intf_thread_t * p_intf = p_main->p_intf;
+
+    if ( p_intf->p_sys->b_loop )
+    {
+        intf_PlaylistDelete( p_main->p_playlist,
+                             p_main->p_playlist->i_size - 1 );
+    }
+    else
+    {
+        intf_PlaylistAdd( p_main->p_playlist, PLAYLIST_END, 
+                          "vlc:loop" );
+    }
+    p_intf->p_sys->b_loop = !p_intf->p_sys->b_loop;
+}
+
 - (void)playSlower
 {
     if( p_input_bank->pp_input[0] != NULL )
@@ -400,7 +452,7 @@ static Intf_VLCWrapper *o_intf = nil;
 - (void)playlistAdd:(NSString *)o_filename
 {
     intf_PlaylistAdd( p_main->p_playlist, PLAYLIST_END, 
-                      [o_filename lossyCString] );
+                      [o_filename fileSystemRepresentation] );
 }
     
 - (void)clearPlaylist
@@ -425,11 +477,18 @@ static Intf_VLCWrapper *o_intf = nil;
     NSString *o_file;
     int i_end = p_main->p_playlist->i_size;
     NSEnumerator *o_enum = [o_files objectEnumerator];
+    intf_thread_t * p_intf = p_main->p_intf;
+
+    if ( p_intf->p_sys->b_loop )
+    {
+        intf_PlaylistDelete( p_main->p_playlist,
+                             p_main->p_playlist->i_size - 1 );
+    }
 
     while( ( o_file = (NSString *)[o_enum nextObject] ) )
     {
         intf_PlaylistAdd( p_main->p_playlist, PLAYLIST_END, 
-                          [o_file lossyCString] );
+                          [o_file fileSystemRepresentation] );
     }
 
     /* end current item, select first added item */
@@ -439,18 +498,31 @@ static Intf_VLCWrapper *o_intf = nil;
     }
 
     intf_PlaylistJumpto( p_main->p_playlist, i_end - 1 );
+
+    if ( p_intf->p_sys->b_loop )
+    {
+        intf_PlaylistAdd( p_main->p_playlist, PLAYLIST_END, 
+                          "vlc:loop" );
+    }
 }
 
 - (void)openDisc:(NSString*)o_type device:(NSString*)o_device title:(int)i_title chapter:(int)i_chapter
 {
     NSString *o_source;
     int i_end = p_main->p_playlist->i_size;
+    intf_thread_t * p_intf = p_main->p_intf;
 
     o_source = [NSString stringWithFormat: @"%@:%@@%d,%d", 
                     o_type, o_device, i_title, i_chapter];
 
+    if ( p_intf->p_sys->b_loop )
+    {
+        intf_PlaylistDelete( p_main->p_playlist,
+                             p_main->p_playlist->i_size - 1 );
+    }
+
     intf_PlaylistAdd( p_main->p_playlist, PLAYLIST_END,
-                      [o_source lossyCString] );
+                      [o_source fileSystemRepresentation] );
 
     /* stop current item, select added item */
     if( p_input_bank->pp_input[0] != NULL )
@@ -459,35 +531,46 @@ static Intf_VLCWrapper *o_intf = nil;
     }
 
     intf_PlaylistJumpto( p_main->p_playlist, i_end - 1 );
+
+    if ( p_intf->p_sys->b_loop )
+    {
+        intf_PlaylistAdd( p_main->p_playlist, PLAYLIST_END, 
+                          "vlc:loop" );
+    }
 }
 
-- (void)openNet:(NSString*)o_protocol addr:(NSString*)o_addr port:(int)i_port baddr:(NSString*)o_baddr
+- (void)openNet:(NSString*)o_addr port:(int)i_port
 {
     NSString *o_source;
     int i_end = p_main->p_playlist->i_size;
+    intf_thread_t * p_intf = p_main->p_intf;
 
     if( p_input_bank->pp_input[0] != NULL )
     {
         p_input_bank->pp_input[0]->b_eof = 1;
     }
 
-    config_PutIntVariable( "network_channel", 0 );
+    config_PutIntVariable( "network-channel", 0 );
 
-    if( o_baddr != nil )
+    o_source = [NSString stringWithFormat: @"udpstream:@%@:%i",
+                o_addr, i_port];
+
+    if ( p_intf->p_sys->b_loop )
     {
-        o_source = [NSString stringWithFormat: @"%@://%@@:%i/%@",
-                        o_protocol, o_addr, i_port, o_baddr];
-    }
-    else
-    {
-        o_source = [NSString stringWithFormat: @"%@://%@@:%i",
-                        o_protocol, o_addr, i_port];
+        intf_PlaylistDelete( p_main->p_playlist,
+                             p_main->p_playlist->i_size - 1 );
     }
 
     intf_PlaylistAdd( p_main->p_playlist, PLAYLIST_END,
-                      [o_source lossyCString] );
+                      [o_source fileSystemRepresentation] );
 
     intf_PlaylistJumpto( p_main->p_playlist, i_end - 1 );
+
+    if ( p_intf->p_sys->b_loop )
+    {
+        intf_PlaylistAdd( p_main->p_playlist, PLAYLIST_END, 
+                          "vlc:loop" );
+    }
 }
 
 - (void)openNetChannel:(NSString*)o_addr port:(int)i_port
@@ -497,15 +580,46 @@ static Intf_VLCWrapper *o_intf = nil;
         p_input_bank->pp_input[0]->b_eof = 1;
     }
 
-    config_PutIntVariable( "network_channel", 1 );
+    config_PutIntVariable( "network-channel", 1 );
 
     if( p_main->p_channel == NULL )
     {
         network_ChannelCreate();
     }
 
-    config_PutPszVariable( "channel_server", (char*)[o_addr lossyCString] );
-    config_PutIntVariable( "channel_port", i_port ); 
+    config_PutPszVariable( "channel-server", (char*)[o_addr lossyCString] );
+    config_PutIntVariable( "channel-port", i_port ); 
+}
+
+- (void)openNetHTTP:(NSString*)o_addr
+{
+    NSString *o_source;
+    int i_end = p_main->p_playlist->i_size;
+    intf_thread_t * p_intf = p_main->p_intf;
+
+    if( p_input_bank->pp_input[0] != NULL )
+    {
+        p_input_bank->pp_input[0]->b_eof = 1;
+    }
+
+    config_PutIntVariable( "network-channel", 0 );
+
+    if ( p_intf->p_sys->b_loop )
+    {
+        intf_PlaylistDelete( p_main->p_playlist,
+                             p_main->p_playlist->i_size - 1 );
+    }
+
+    intf_PlaylistAdd( p_main->p_playlist, PLAYLIST_END,
+                      [o_addr fileSystemRepresentation] );
+
+    intf_PlaylistJumpto( p_main->p_playlist, i_end - 1 );
+
+    if ( p_intf->p_sys->b_loop )
+    {
+        intf_PlaylistAdd( p_main->p_playlist, PLAYLIST_END, 
+                          "vlc:loop" );
+    }
 }
 
 - (void)toggleProgram:(id)sender
@@ -653,7 +767,7 @@ static Intf_VLCWrapper *o_intf = nil;
     NSMenu *o_main_menu;
     NSMenuItem *o_controls_item;
     NSMenuItem *o_program_item, *o_title_item, *o_chapter_item, *o_language_item,
-               *o_subtitle_item;
+               *o_subtitle_item, *o_next_channel_item, *o_prev_channel_item;
     input_thread_t * p_input = p_input_bank->pp_input[0];
 
     o_main_menu  = [NSApp mainMenu];
@@ -663,6 +777,8 @@ static Intf_VLCWrapper *o_intf = nil;
     o_chapter_item = [[o_controls_item submenu] itemWithTitle: @"Chapter"]; 
     o_language_item = [[o_controls_item submenu] itemWithTitle: @"Language"]; 
     o_subtitle_item = [[o_controls_item submenu] itemWithTitle: @"Subtitles"]; 
+    o_next_channel_item = [[o_controls_item submenu] itemWithTag: 13]; 
+    o_prev_channel_item = [[o_controls_item submenu] itemWithTag: 12]; 
 
     if( p_input == NULL )
     {
@@ -811,7 +927,7 @@ static Intf_VLCWrapper *o_intf = nil;
     
                 o_item = [o_chapter addItemWithTitle: o_menu_title
                         action: pf_toggle_chapter keyEquivalent: @""];
-                [o_item setTag: i];
+                [o_item setTag: i + 1];
                 [o_item setTarget: self];
                 if( ( p_input->stream.p_selected_area->i_part == i + 1 ) )
                 {
@@ -873,9 +989,10 @@ static Intf_VLCWrapper *o_intf = nil;
                 }
     
                 o_item = [o_language addItemWithTitle: o_menu_title
-                        action: pf_toggle_language keyEquivalent: @""];
+                          action: pf_toggle_language keyEquivalent: @""];
                 [o_item setTag: i];
                 [o_item setTarget: self];
+                [o_item setEnabled: 1];
                 if( p_es->p_decoder_fifo != NULL )
                 {
                     [o_item setState: 1];
@@ -901,9 +1018,10 @@ static Intf_VLCWrapper *o_intf = nil;
                 }
     
                 o_item = [o_subtitle addItemWithTitle: o_menu_title
-                        action: pf_toggle_subtitle keyEquivalent: @""];
+                          action: pf_toggle_subtitle keyEquivalent: @""];
                 [o_item setTag: i];
                 [o_item setTarget: self];
+                [o_item setEnabled: 1];
                 if( p_es->p_decoder_fifo != NULL )
                 {
                     [o_item setState: 1];
