@@ -2,7 +2,7 @@
  * spu_decoder.c : spu decoder thread
  *****************************************************************************
  * Copyright (C) 2000-2001 VideoLAN
- * $Id: spu_decoder.c,v 1.23 2002/05/19 15:50:02 stef Exp $
+ * $Id: spu_decoder.c,v 1.24.2.1 2002/06/02 13:41:55 sam Exp $
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
  *          Rudolf Cornelissen <rag.cornelissen@inter.nl.net>
@@ -320,11 +320,12 @@ static void ParsePacket( spudec_thread_t *p_spudec )
     }
 
     /* Get RLE data */
-    for( i_offset = 0;
-         i_offset + SPU_CHUNK_SIZE < p_spudec->i_rle_size;
+    for( i_offset = 0; i_offset < p_spudec->i_rle_size;
          i_offset += SPU_CHUNK_SIZE )
     {
-        GetChunk( &p_spudec->bit_stream, p_src + i_offset, SPU_CHUNK_SIZE );
+        GetChunk( &p_spudec->bit_stream, p_src + i_offset,
+                  ( i_offset + SPU_CHUNK_SIZE < p_spudec->i_rle_size ) ?
+                  SPU_CHUNK_SIZE : p_spudec->i_rle_size - i_offset );
 
         /* Abort subtitle parsing if we were requested to stop */
         if( p_spudec->p_fifo->b_die )
@@ -335,9 +336,6 @@ static void ParsePacket( spudec_thread_t *p_spudec )
         }
     }
 
-    GetChunk( &p_spudec->bit_stream, p_src + i_offset,
-              p_spudec->i_rle_size - i_offset );
-
 #if 0
     /* Dump the subtitle info */
     intf_WarnHexDump( 5, p_spu->p_sys->p_data, p_spudec->i_rle_size );
@@ -918,7 +916,7 @@ static void RenderSPU( const vout_thread_t *p_vout, picture_t *p_pic,
     p_dest = p_pic->p->p_pixels + ( i_width >> 6 ) * 2
               /* Add the picture coordinates and the SPU coordinates */
               + ( (p_spu->i_x * i_xscale) >> 6 ) * 2
-              + ( (p_spu->i_y * i_yscale) >> 6 ) * p_vout->output.i_width * 2;
+              + ( (p_spu->i_y * i_yscale) >> 6 ) * p_pic->p->i_pitch;
 
     /* Draw until we reach the bottom of the subtitle */
     for( i_y = 0 ; i_y < i_height ; )
@@ -930,7 +928,7 @@ static void RenderSPU( const vout_thread_t *p_vout, picture_t *p_pic,
         if( i_ytmp + 1 >= ( i_y >> 6 ) )
         {
             /* Just one line : we precalculate i_y >> 6 */
-            i_yreal = p_vout->output.i_width * 2 * i_ytmp;
+            i_yreal = p_pic->p->i_pitch * i_ytmp;
 
             /* Draw until we reach the end of the line */
             for( i_x = i_width ; i_x ; )
@@ -966,8 +964,8 @@ static void RenderSPU( const vout_thread_t *p_vout, picture_t *p_pic,
         }
         else
         {
-            i_yreal = p_vout->output.i_width * 2 * i_ytmp;
-            i_ynext = p_vout->output.i_width * 2 * i_y >> 6;
+            i_yreal = p_pic->p->i_pitch * i_ytmp;
+            i_ynext = p_pic->p->i_pitch * i_y >> 6;
 
             /* Draw until we reach the end of the line */
             for( i_x = i_width ; i_x ; )
@@ -984,7 +982,7 @@ static void RenderSPU( const vout_thread_t *p_vout, picture_t *p_pic,
                 case 0x0f:
                     i_len = i_xscale * ( *p_source++ >> 2 );
                     for( i_ytmp = i_yreal ; i_ytmp < i_ynext ;
-                         i_ytmp += p_vout->output.i_width * 2 )
+                         i_ytmp += p_pic->p->i_pitch )
                     {
                         memset( p_dest - 2 * ( i_x >> 6 ) + i_ytmp,
                                 p_clut16[ i_color ],
@@ -997,7 +995,7 @@ static void RenderSPU( const vout_thread_t *p_vout, picture_t *p_pic,
                     /* FIXME: we should do transparency */
                     i_len = i_xscale * ( *p_source++ >> 2 );
                     for( i_ytmp = i_yreal ; i_ytmp < i_ynext ;
-                         i_ytmp += p_vout->output.i_width * 2 )
+                         i_ytmp += p_pic->p->i_pitch )
                     {
                         memset( p_dest - 2 * ( i_x >> 6 ) + i_ytmp,
                                 p_clut16[ i_color ],
@@ -1033,7 +1031,7 @@ static void RenderSPU( const vout_thread_t *p_vout, picture_t *p_pic,
     p_dest = p_pic->p->p_pixels + ( i_width >> 6 ) * 4
               /* Add the picture coordinates and the SPU coordinates */
               + ( (p_spu->i_x * i_xscale) >> 6 ) * 4
-              + ( (p_spu->i_y * i_yscale) >> 6 ) * p_vout->output.i_width * 4;
+              + ( (p_spu->i_y * i_yscale) >> 6 ) * p_pic->p->i_pitch;
 
     /* Draw until we reach the bottom of the subtitle */
     for( i_y = 0 ; i_y < i_height ; )
@@ -1045,7 +1043,7 @@ static void RenderSPU( const vout_thread_t *p_vout, picture_t *p_pic,
         if( i_ytmp + 1 >= ( i_y >> 6 ) )
         {
             /* Just one line : we precalculate i_y >> 6 */
-            i_yreal = p_vout->output.i_width * 4 * i_ytmp;
+            i_yreal = p_pic->p->i_pitch * i_ytmp;
 
             /* Draw until we reach the end of the line */
             for( i_x = i_width ; i_x ; )
@@ -1079,8 +1077,8 @@ static void RenderSPU( const vout_thread_t *p_vout, picture_t *p_pic,
         }
         else
         {
-            i_yreal = p_vout->output.i_width * 4 * i_ytmp;
-            i_ynext = p_vout->output.i_width * 4 * i_y >> 6;
+            i_yreal = p_pic->p->i_pitch * i_ytmp;
+            i_ynext = p_pic->p->i_pitch * i_y >> 6;
 
             /* Draw until we reach the end of the line */
             for( i_x = i_width ; i_x ; )
@@ -1097,7 +1095,7 @@ static void RenderSPU( const vout_thread_t *p_vout, picture_t *p_pic,
                 case 0x0f:
                     i_len = i_xscale * ( *p_source++ >> 2 );
                     for( i_ytmp = i_yreal ; i_ytmp < i_ynext ;
-                         i_ytmp += p_vout->output.i_width * 4 )
+                         i_ytmp += p_pic->p->i_pitch )
                     {
                         memset( p_dest - 4 * ( i_x >> 6 ) + i_ytmp,
                                 p_clut32[ i_color ],
@@ -1110,7 +1108,7 @@ static void RenderSPU( const vout_thread_t *p_vout, picture_t *p_pic,
                     /* FIXME: we should do transparency */
                     i_len = i_xscale * ( *p_source++ >> 2 );
                     for( i_ytmp = i_yreal ; i_ytmp < i_ynext ;
-                         i_ytmp += p_vout->output.i_width * 4 )
+                         i_ytmp += p_pic->p->i_pitch )
                     {
                         memset( p_dest - 4 * ( i_x >> 6 ) + i_ytmp,
                                 p_clut32[ i_color ],
@@ -1202,4 +1200,3 @@ static void RenderSPU( const vout_thread_t *p_vout, picture_t *p_pic,
         break;
     }
 }
-
