@@ -185,6 +185,11 @@ void __fastcall TMainFrameDlg::MenuExitClick( TObject *Sender )
     Close();
 }
 //---------------------------------------------------------------------------
+void __fastcall TMainFrameDlg::MenuHideinterfaceClick( TObject *Sender )
+{
+     this->SendToBack();
+}
+//---------------------------------------------------------------------------
 void __fastcall TMainFrameDlg::MenuFullscreenClick( TObject *Sender )
 {
     if( p_vout_bank->i_count )
@@ -534,27 +539,8 @@ void __fastcall TMainFrameDlg::ButtonGoClick( TObject *Sender )
     intf_WarnMsg( 3, "intf info: joining channel %d", i_channel );
 
     vlc_mutex_lock( &p_intf->change_lock );
-    if( p_input_bank->pp_input[0] != NULL )
-    {
-        /* end playing item */
-        p_input_bank->pp_input[0]->b_eof = 1;
-
-        /* update playlist */
-        vlc_mutex_lock( &p_main->p_playlist->change_lock );
-
-        p_main->p_playlist->i_index--;
-        p_main->p_playlist->b_stopped = 1;
-
-        vlc_mutex_unlock( &p_main->p_playlist->change_lock );
-
-        /* FIXME: ugly hack to close input and outputs */
-        p_intf->pf_manage( p_intf );
-    }
 
     network_ChannelJoin( i_channel );
-
-    /* FIXME 2 */
-    p_main->p_playlist->b_stopped = 0;
     p_intf->pf_manage( p_intf );
 
     vlc_mutex_unlock( &p_intf->change_lock );
@@ -623,7 +609,7 @@ void __fastcall TMainFrameDlg::ModeManage()
                 break;
         }
 
-        i_Height = StatusBar->Height + ActiveGB->Height + ToolBar->Height + 47;
+        i_Height = StatusBar->Height + ActiveGB->Height + ToolBar->Height + 54;
 
         /* initialize and show slider for seekable streams */
         if( p_input_bank->pp_input[0]->stream.b_seekable )
@@ -655,24 +641,24 @@ void __fastcall TMainFrameDlg::ModeManage()
         {
             GroupBoxNetwork->Visible = true;
             LabelChannel->Visible = true;
-            i_Height += GroupBoxNetwork->Height;
+            i_Height += GroupBoxNetwork->Height + 7;
         }
         else
         {
             /* add space between tolbar and statusbar when
              * nothing is displayed; isn't it nicer ? :) */ 
-            i_Height += 18;
-
-            /* unsensitize menus */
-            MenuProgram->Enabled = false;
-            MenuTitle->Enabled = false;
-            MenuChapter->Enabled = false;
-            MenuAudio->Enabled = false;
-            MenuSubtitles->Enabled = false;
-            PopupNavigation->Enabled = false;
-            PopupAudio->Enabled = false;
-            PopupSubtitles->Enabled = false;
+            i_Height += 17;
         }
+
+        /* unsensitize menus */
+        MenuProgram->Enabled = false;
+        MenuTitle->Enabled = false;
+        MenuChapter->Enabled = false;
+        MenuAudio->Enabled = false;
+        MenuSubtitles->Enabled = false;
+        PopupNavigation->Enabled = false;
+        PopupAudio->Enabled = false;
+        PopupSubtitles->Enabled = false;
     }
 
     /* resize main window */
