@@ -1,8 +1,8 @@
 /*****************************************************************************
  * input_programs.c: es_descriptor_t, pgrm_descriptor_t management
  *****************************************************************************
- * Copyright (C) 1999-2001 VideoLAN
- * $Id: input_programs.c,v 1.80 2002/04/17 17:00:58 jobi Exp $
+ * Copyright (C) 1999-2002 VideoLAN
+ * $Id: input_programs.c,v 1.88 2002/05/17 00:58:14 sam Exp $
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *
@@ -35,8 +35,6 @@
 #include "input_ext-dec.h"
 #include "input_ext-plugins.h"
 
-#include "debug.h"
-
 /*
  * NOTICE : all of these functions expect you to have taken the lock on
  * p_input->stream.lock
@@ -128,7 +126,7 @@ pgrm_descriptor_t * input_FindProgram( input_thread_t * p_input, u16 i_pgrm_id )
         }
     }
 
-    return( NULL );
+    return NULL;
 }
 
 /*****************************************************************************
@@ -146,13 +144,13 @@ pgrm_descriptor_t * input_AddProgram( input_thread_t * p_input,
     p_input->stream.i_pgrm_number++;
     p_input->stream.pp_programs = realloc( p_input->stream.pp_programs,
                                            p_input->stream.i_pgrm_number
-                                            * sizeof(pgrm_descriptor_t *) );
+                                           * sizeof(pgrm_descriptor_t *) );
     if( p_input->stream.pp_programs == NULL )
     {
         intf_ErrMsg( "Unable to realloc memory in input_AddProgram" );
         return( NULL );
     }
-    
+
     /* Allocate the structure to store this description */
     p_input->stream.pp_programs[i_pgrm_index] =
                                         malloc( sizeof(pgrm_descriptor_t) );
@@ -204,7 +202,20 @@ void input_DelProgram( input_thread_t * p_input, pgrm_descriptor_t * p_pgrm )
 {
     int i_pgrm_index;
 
-    ASSERT( p_pgrm );
+    /* Find the program in the programs table */
+    for( i_pgrm_index = 0; i_pgrm_index < p_input->stream.i_pgrm_number;
+         i_pgrm_index++ )
+    {
+        if( p_input->stream.pp_programs[i_pgrm_index] == p_pgrm )
+            break;
+    }
+
+    /* If the program wasn't found, do nothing */
+    if( i_pgrm_index == p_input->stream.i_pgrm_number )
+    {
+        intf_ErrMsg( "input error: program does not belong to this input" );
+        return;
+    }
 
     /* Free the structures that describe the es that belongs to that program */
     while( p_pgrm->i_es_number )
@@ -218,27 +229,26 @@ void input_DelProgram( input_thread_t * p_input, pgrm_descriptor_t * p_pgrm )
         free( p_pgrm->p_demux_data );
     }
 
-    /* Find the program in the programs table */
-    for( i_pgrm_index = 0; i_pgrm_index < p_input->stream.i_pgrm_number;
-         i_pgrm_index++ )
-    {
-        if( p_input->stream.pp_programs[i_pgrm_index] == p_pgrm )
-            break;
-    }
-
     /* Remove this program from the stream's list of programs */
     p_input->stream.i_pgrm_number--;
 
     p_input->stream.pp_programs[i_pgrm_index] =
         p_input->stream.pp_programs[p_input->stream.i_pgrm_number];
-    p_input->stream.pp_programs = realloc( p_input->stream.pp_programs,
-                                           p_input->stream.i_pgrm_number
-                                            * sizeof(pgrm_descriptor_t *) );
-
-    if( p_input->stream.i_pgrm_number && p_input->stream.pp_programs == NULL)
+    if( p_input->stream.i_pgrm_number ) 
     {
-        intf_ErrMsg( "input error: unable to realloc program list"
-                     " in input_DelProgram" );
+        p_input->stream.pp_programs = realloc( p_input->stream.pp_programs,
+                                               p_input->stream.i_pgrm_number
+                                               * sizeof(pgrm_descriptor_t *) );
+        if( p_input->stream.pp_programs == NULL )
+        {
+            intf_ErrMsg( "input error: unable to realloc program list"
+                         " in input_DelProgram" );
+        }
+    }
+    else
+    {
+        free( p_input->stream.pp_programs );
+        p_input->stream.pp_programs = NULL;
     }
 
     /* Free the description of this program */
@@ -259,13 +269,13 @@ input_area_t * input_AddArea( input_thread_t * p_input )
     p_input->stream.i_area_nb++;
     p_input->stream.pp_areas = realloc( p_input->stream.pp_areas,
                                         p_input->stream.i_area_nb
-                                            * sizeof(input_area_t *) );
+                                        * sizeof(input_area_t *) );
     if( p_input->stream.pp_areas == NULL )
     {
         intf_ErrMsg( "Unable to realloc memory in input_AddArea" );
         return( NULL );
     }
-    
+
     /* Allocate the structure to store this description */
     p_input->stream.pp_areas[i_area_index] =
                                         malloc( sizeof(input_area_t) );
@@ -317,7 +327,7 @@ int input_SetProgram( input_thread_t * p_input, pgrm_descriptor_t * p_new_prg )
     if( p_main->b_audio )
     {
         /* Default is the first one */
-        i_required_audio_es = config_GetIntVariable( "input_channel" );
+        i_required_audio_es = config_GetIntVariable( "audio-channel" );
         if( i_required_audio_es < 0 )
         {
             i_required_audio_es = 1;
@@ -332,7 +342,7 @@ int input_SetProgram( input_thread_t * p_input, pgrm_descriptor_t * p_new_prg )
     if( p_main->b_video )
     {
         /* for spu, default is none */
-        i_required_spu_es = config_GetIntVariable( "input_subtitle" );
+        i_required_spu_es = config_GetIntVariable( "spu-channel" );
         if( i_required_spu_es < 0 )
         {
             i_required_spu_es = 0;
@@ -395,8 +405,6 @@ void input_DelArea( input_thread_t * p_input, input_area_t * p_area )
 {
     int i_area_index;
 
-    ASSERT( p_area );
-
     /* Find the area in the areas table */
     for( i_area_index = 0; i_area_index < p_input->stream.i_area_nb;
          i_area_index++ )
@@ -405,19 +413,34 @@ void input_DelArea( input_thread_t * p_input, input_area_t * p_area )
             break;
     }
 
+    /* If the area wasn't found, do nothing */
+    if( i_area_index == p_input->stream.i_area_nb )
+    {
+        intf_ErrMsg( "input error: area does not belong to this input" );
+        return;
+    }
+
     /* Remove this area from the stream's list of areas */
     p_input->stream.i_area_nb--;
 
     p_input->stream.pp_areas[i_area_index] =
         p_input->stream.pp_areas[p_input->stream.i_area_nb];
-    p_input->stream.pp_areas = realloc( p_input->stream.pp_areas,
-                                           p_input->stream.i_area_nb
+    if( p_input->stream.i_area_nb )
+    {
+        p_input->stream.pp_areas = realloc( p_input->stream.pp_areas,
+                                            p_input->stream.i_area_nb
                                             * sizeof(input_area_t *) );
 
-    if( p_input->stream.i_area_nb && p_input->stream.pp_areas == NULL)
+        if( p_input->stream.pp_areas == NULL )
+        {
+            intf_ErrMsg( "input error: unable to realloc area list"
+                         " in input_DelArea" );
+        }
+    }
+    else
     {
-        intf_ErrMsg( "input error: unable to realloc area list"
-                     " in input_DelArea" );
+        free( p_input->stream.pp_areas );
+        p_input->stream.pp_areas = NULL;
     }
 
     /* Free the description of this area */
@@ -440,7 +463,7 @@ es_descriptor_t * input_FindES( input_thread_t * p_input, u16 i_es_id )
         }
     }
 
-    return( NULL );
+    return NULL;
 }
 
 /*****************************************************************************
@@ -471,6 +494,7 @@ es_descriptor_t * input_AddES( input_thread_t * p_input,
         intf_ErrMsg( "Unable to realloc memory in input_AddES" );
         return( NULL );
     }
+
     p_input->stream.pp_es[p_input->stream.i_es_number - 1] = p_es;
 
     /* Init its values */
@@ -480,9 +504,7 @@ es_descriptor_t * input_AddES( input_thread_t * p_input,
     p_es->p_decoder_fifo = NULL;
     p_es->b_audio = 0;
     p_es->i_cat = UNKNOWN_ES;
-#ifdef HAVE_SATELLITE
-    p_es->i_dmx_fd = 0;
-#endif
+    p_es->i_demux_fd = 0;
 
     if( i_data_len )
     {
@@ -511,6 +533,7 @@ es_descriptor_t * input_AddES( input_thread_t * p_input,
             intf_ErrMsg( "Unable to realloc memory in input_AddES" );
             return( NULL );
         }
+
         p_pgrm->pp_es[p_pgrm->i_es_number - 1] = p_es;
         p_es->p_pgrm = p_pgrm;
     }
@@ -530,7 +553,21 @@ void input_DelES( input_thread_t * p_input, es_descriptor_t * p_es )
     int                     i_index, i_es_index;
     pgrm_descriptor_t *     p_pgrm;
 
-    ASSERT( p_es );
+    /* Find the ES in the ES table */
+    for( i_es_index = 0; i_es_index < p_input->stream.i_es_number;
+         i_es_index++ )
+    {
+        if( p_input->stream.pp_es[i_es_index] == p_es )
+            break;
+    }
+
+    /* If the ES wasn't found, do nothing */
+    if( i_es_index == p_input->stream.i_es_number )
+    {
+        intf_ErrMsg( "input error: ES does not belong to this input" );
+        return;
+    }
+
     p_pgrm = p_es->p_pgrm;
 
     /* Kill associated decoder, if any. */
@@ -549,12 +586,21 @@ void input_DelES( input_thread_t * p_input, es_descriptor_t * p_es )
             {
                 p_pgrm->i_es_number--;
                 p_pgrm->pp_es[i_index] = p_pgrm->pp_es[p_pgrm->i_es_number];
-                p_pgrm->pp_es = realloc( p_pgrm->pp_es,
-                                         p_pgrm->i_es_number
-                                          * sizeof(es_descriptor_t *));
-                if( p_pgrm->i_es_number && p_pgrm->pp_es == NULL )
+                if( p_pgrm->i_es_number )
                 {
-                    intf_ErrMsg( "Unable to realloc memory in input_DelES" );
+                    p_pgrm->pp_es = realloc( p_pgrm->pp_es,
+                                             p_pgrm->i_es_number
+                                              * sizeof(es_descriptor_t *));
+                    if( p_pgrm->pp_es == NULL )
+                    {
+                        intf_ErrMsg( "Unable to realloc memory in "
+                                     "input_DelES" );
+                    }
+                }
+                else
+                {
+                    free( p_pgrm->pp_es );
+                    p_pgrm->pp_es = NULL;
                 }
                 break;
             }
@@ -567,27 +613,28 @@ void input_DelES( input_thread_t * p_input, es_descriptor_t * p_es )
         free( p_es->p_demux_data );
     }
 
-    /* Find the ES in the ES table */
-    for( i_es_index = 0; i_es_index < p_input->stream.i_es_number;
-         i_es_index++ )
-    {
-        if( p_input->stream.pp_es[i_es_index] == p_es )
-            break;
-    }
-
-    /* Free the ES */
-    free( p_es );
+    /* Remove this ES from the stream's list of ES */
     p_input->stream.i_es_number--;
     p_input->stream.pp_es[i_es_index] =
                     p_input->stream.pp_es[p_input->stream.i_es_number];
-    p_input->stream.pp_es = realloc( p_input->stream.pp_es,
-                                     p_input->stream.i_es_number
-                                      * sizeof(es_descriptor_t *));
-    if( p_input->stream.i_es_number && p_input->stream.pp_es == NULL )
+    if( p_input->stream.i_es_number )
     {
-        intf_ErrMsg( "Unable to realloc memory in input_DelES" );
+        p_input->stream.pp_es = realloc( p_input->stream.pp_es,
+                                         p_input->stream.i_es_number
+                                          * sizeof(es_descriptor_t *));
+        if( p_input->stream.pp_es == NULL )
+        {
+            intf_ErrMsg( "Unable to realloc memory in input_DelES" );
+        }
+    }
+    else
+    {
+        free( p_input->stream.pp_es );
+        p_input->stream.pp_es = NULL;
     }
     
+    /* Free the ES */
+    free( p_es );
 }
 
 /*****************************************************************************
@@ -632,6 +679,10 @@ int input_SelectES( input_thread_t * p_input, es_descriptor_t * p_es )
 
     case MPEG1_VIDEO_ES:
     case MPEG2_VIDEO_ES:
+    case MPEG4_VIDEO_ES:
+    case MSMPEG4v1_VIDEO_ES:
+    case MSMPEG4v2_VIDEO_ES:
+    case MSMPEG4v3_VIDEO_ES:
     case DVD_SPU_ES:
         if( p_main->b_video )
         {
@@ -696,15 +747,23 @@ int input_UnselectES( input_thread_t * p_input, es_descriptor_t * p_es )
         p_input->stream.pp_selected_es[i_index] = 
           p_input->stream.pp_selected_es[p_input->stream.i_selected_es_number];
 
-        p_input->stream.pp_selected_es = realloc(
+        if( p_input->stream.i_selected_es_number )
+        {
+            p_input->stream.pp_selected_es = realloc(
                                            p_input->stream.pp_selected_es,
                                            p_input->stream.i_selected_es_number
-                                            * sizeof(es_descriptor_t *) );
-
-        if( p_input->stream.pp_selected_es == NULL )
+                                           * sizeof(es_descriptor_t *) );
+            if( p_input->stream.pp_selected_es == NULL )
+            {
+                intf_ErrMsg( "Unable to realloc memory in input_UnselectES" );
+                return( -1 );
+            }
+        }
+        else
         {
-            intf_WarnMsg( 4, "input: no more selected ES in input_UnselectES" );
-            return( 1 );
+            free( p_input->stream.pp_selected_es );   
+            p_input->stream.pp_selected_es = NULL;
+            intf_WarnMsg( 4, "input: no more selected ES in input_UnselectES" );            return( 1 );
         }
     }
 
